@@ -10,12 +10,6 @@ def cli():
 
 @cli.command()
 @click.option('-url', type=str, help='Paste your link of the repo')
-@click.option('-m',type=str,help = "Commit message ")
 
-def initpush(url,m):
-    click.echo(gf.init_push(url,m))
-
-
-@cli.command()
-def status():
-    click.echo(gf.status())
\ No newline at end of file
+def initpush(url):
+    click.echo(gf.init_push(url))
\ No newline at end of file
